@@ -1,6 +1,6 @@
 from mingus.core import progressions, diatonic
 from mingus.containers.NoteContainer import NoteContainer
-from time import sleep
+from time import sleep, time
 from random import random
 from mingus.core import chords
 
@@ -13,7 +13,7 @@ class Sequencer:
 	meter = (4,4)
 	iterations = 0
 	play_iterations = 32
-	wild = 0.4
+	wild = 0.7
 	paint_function = None
 	refresh_function = None
 	update_function = None
@@ -36,8 +36,17 @@ class Sequencer:
 		self.reset_state()
 	
 	def block_tick(self):
-		sleep(self.block.get_tick_length(\
-			self.tick, self.tick_length))
+		# Execution time of current tick
+		exec_time = time() - self.tick_start
+
+		tick_length = self.block.get_tick_length(self.tick, \
+				self.tick_length)
+
+		if exec_time > tick_length:
+			print "Tick Overflow!"
+		else:
+			tick_length -= exec_time
+		sleep(tick_length)
 		self.set_bpm(self.block.get_bpm(self.iterations))
 
 
@@ -66,6 +75,7 @@ class Sequencer:
 		i = 0
 		while i < len(self.chords) * ticks:
 
+			self.tick_start = time()
 			chord = self.chords[ i / ticks ]
 
 			if self.refresh_function != None:
